@@ -3,7 +3,7 @@ package LCS::BV;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 #use utf8;
 
 our $width = int 0.999+log(~0)/log(2);
@@ -39,7 +39,7 @@ sub LCS {
   my $positions;
   my @lcs;
 
-  if ($amax < 64 ) {
+  if ($amax < $width ) {
     $positions->{$a->[$_]} |= 1 << ($_ % $width) for $amin..$amax;
 
     my $S = ~0;
